@@ -18,9 +18,9 @@ __docformat__ = "restructuredtext en"
 
 from cubicweb import UnknownEid
 from cubicweb.utils import json
-from cubicweb.web.views import reledit
-from cubicweb.web import RemoteCallFailed
-from cubicweb.web.views.ajaxcontroller import ajaxfunc
+from cubicweb_web.views import reledit
+from cubicweb_web import RemoteCallFailed
+from cubicweb_web.views.ajaxcontroller import ajaxfunc
 
 
 @ajaxfunc
