@@ -31,11 +31,11 @@ from cubicweb import neg_role, appobject
 from cubicweb.schema import display_name
 from cubicweb.utils import json_dumps
 from cubicweb.predicates import non_final_entity, match_kwargs
-from cubicweb.view import EntityView
-from cubicweb.web import stdmsgs
-from cubicweb.web.formwidgets import Button, SubmitButton
+from cubicweb_web.view import EntityView
+from cubicweb_web import stdmsgs
+from cubicweb_web.formwidgets import Button, SubmitButton
 
-from cubicweb.web.views import uicfg, reledit as old_cw_reledit
+from cubicweb_web.views import uicfg, reledit as old_cw_reledit
 
 uicfg.ReleditTags._keys = frozenset(
     "novalue_label novalue_include_rtype " "reload evid rvid edit_target".split()
